chicken_turtle_util.sqlalchemy
==============================

.. automodule:: chicken_turtle_util.sqlalchemy

.. autosummary::
   :nosignatures:

   log_sql
   pretty_sql

.. autofunction:: log_sql
.. autofunction:: pretty_sql
